==> jc-1.4.0.tar.gz: org/dellroad/jc/BootstrapObjectGenerator__24DirMatcher.h <==
// class org.dellroad.jc.BootstrapObjectGenerator$DirMatcher

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a4bf00613aa8cc36 org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher
// @dep_class 25215c5cc24f2d81 org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher

// header file dependencies
// @dep_header org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher

#include "org/dellroad/jc/BootstrapObjectGenerator__24SearchpathMatcher.h"

#ifndef _JC_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher_H_
#define _JC_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object;

typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vmethods	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vmethods;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtable	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtable;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype;

// Constructors
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method$_init$538ee07130435a5e(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_io_File$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method$addFiles$5a3c1c3d2912ec8a(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_io_File$object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_object *);
extern struct _jc_object *_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method$getMatches$65d62d43654fc8a6(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_lang_String$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method_info$addFiles$5a3c1c3d2912ec8a;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method_info$getMatches$65d62d43654fc8a6;

// Virtual methods structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vmethods {
	void	(*addFiles$5a3c1c3d2912ec8a)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_io_File$object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_object *);
	struct _jc_object	*(*getMatches$65d62d43654fc8a6)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_lang_String$object *, jint);
};

// Vtable
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher;
};

// Vtype
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_refs {
	struct _jc_java_io_File$object	*topDir;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$refs {
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher;
};

// Object instance structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object {
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype	*vtype;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$class_object;

#endif	/* _JC_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/BootstrapObjectGenerator__24DirMatcher.h <==
// class org.dellroad.jc.BootstrapObjectGenerator$DirMatcher

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a4bf00613aa8cc36 org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher
// @dep_class 25215c5cc24f2d81 org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher

// header file dependencies
// @dep_header org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher

#include "org/dellroad/jc/BootstrapObjectGenerator__24SearchpathMatcher.h"

#ifndef _JC_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher_H_
#define _JC_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object;

typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vmethods	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vmethods;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtable	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtable;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype;

// Constructors
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method$_init$538ee07130435a5e(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method$addFiles$5a3c1c3d2912ec8a(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_io_File$object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method$getMatches$65d62d43654fc8a6(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method_info$addFiles$5a3c1c3d2912ec8a;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$method_info$getMatches$65d62d43654fc8a6;

// Virtual methods structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vmethods {
	void	(*addFiles$5a3c1c3d2912ec8a)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_io_File$object *, struct _jc_java_lang_String$object *, jboolean, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getMatches$65d62d43654fc8a6)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher;
};

// Vtype
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_refs {
	struct _jc_java_io_File$object	*topDir;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$refs {
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher;
};

// Object instance structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$object {
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype	*vtype;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$vtype _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher$class_object;

#endif	/* _JC_org_dellroad_jc_BootstrapObjectGenerator__24DirMatcher_H_ */
